## AHBicht JSON Schemas

This directory contains [JSON Schema Draft v7](https://json-schema.org/specification-links.html#draft-7) compatible JSON Schemas.
You may use these schemas to [autogenerate classes in the language of your choice](https://json-schema.org/implementations.html#code-generation).
This is thought to reduce manual efforts and allow for easy integration of AHBicht with other components (for example a frontend).

### Autogenerate the Schemas using [`marshmallow-jsonschema`](https://github.com/fuhrysteve/marshmallow-jsonschema)

The files in this directory are autogenerated from the marshmallow classes that are also used for (de-)serialization.
There is a tox environment that executes [`generate_json_schemas.py`](generate_json_schemas.py) and overwrites any `.json` files in this directory.
Simply run:
```bash
tox -e json_schemas
```
